#! /bin/sh
#
# Copyright (c) 1995-2002 Quadralay Corporation.  All rights reserved.
#
#$Id: install.sh,v 1.14 2002/02/27 18:37:01 stockett Exp $

PATH="/bin:/usr/bin:${PATH}"
export PATH

cleanup() {
  if [ -f "${APICLIENTS}" ]; then
    while [ "`grep WWPSE \"${APICLIENTS}\"`" != "" ]
    do
      rm -f "${APICLIENTS}.new";

      # Determine on which line Publisher entry exists
      #
      GREP=`grep -n WWPSE "${APICLIENTS}"`;
      LINENUMBER=`expr "${GREP}" : '\([0-9]*\)'`;

      # Publisher inserts it's WWPSE line 1 before this one
      # and ends it 4 lines after this.  Add one more to these
      # values to skip the APIclient block completely.
      #
      HEADLINE=`expr ${LINENUMBER} - 2`;
      TAILLINE=`expr ${LINENUMBER} + 5`;

      if [ ${HEADLINE} -lt 0 ] ; then
        HEADLINE=0;
      fi

      head -${HEADLINE} "${APICLIENTS}" >  "${APICLIENTS}.new";
      tail +${TAILLINE} "${APICLIENTS}" >> "${APICLIENTS}.new";

      cp "${APICLIENTS}.new" "${APICLIENTS}";
      rm -f "${APICLIENTS}.new";
    done
  else
    touch "${APICLIENTS}"
  fi
}

global() {
  SRCDIR=`pwd`
  for lang in ${LANGS}
  do
    APICLIENTS="${FRAMEDIR}/fminit/${lang}/APIArea/apiclients"

    if [ -f "${APICLIENTS}" ]; then
      echo "Studying the ${APICLIENTS} file..."

      cleanup;

      echo "<APIclient" >> "${APICLIENTS}"
      echo "        <Name WWPSE7>" >> "${APICLIENTS}"
      echo "        <CommandLine \"\$FMHOME/webworks/bin/fa.wpubfm7\">" >> "${APICLIENTS}"
      echo "        <Description WebWorks API Client>" >> "${APICLIENTS}"
      echo "        <Products Maker MakerSGML>" >> "${APICLIENTS}"
      echo ">" >> "${APICLIENTS}"
    fi
  done
}


WebWorksPublisher_SetupCJKFonts()
{
  FRAMEDIR="${1}"
  SRCDIR="${2}"

  FMCIDDIR="${FRAMEDIR}/fminit/fontdir"
  FMMAPDIR="${FRAMEDIR}/fminit/fontdir/cmap"
  WWPCIDDIR="${SRCDIR}/lib/gs/cjk/CIDFont"
  WWPMAPDIR="${SRCDIR}/lib/gs/cjk/CMap"

  if [ -d "${FMCIDDIR}" ]; then
    echo "Setting up required symbolic links to CJK fonts in FMHOME..."

    # Handle fonts

    rm -f "${WWPCIDDIR}"

    mkdir "${WWPCIDDIR}"

    ln -s ${FMCIDDIR}/ja/* ${WWPCIDDIR}
    ln -s ${FMCIDDIR}/ko/* ${WWPCIDDIR}
    ln -s ${FMCIDDIR}/zh/* ${WWPCIDDIR}
    ln -s ${FMCIDDIR}/zh_TW/* ${WWPCIDDIR}

    # Handle font maps

    rm -rf ${WWPMAPDIR}

    mkdir "${WWPMAPDIR}"

    ln -s ${FMMAPDIR}/* ${WWPMAPDIR}
  fi
}

usage()
{
  echo "Usage: install.sh <FMHOME> <Languages> <Platforms>"
  echo ""
  echo "<Languages> = Comma delimited of 1 or more of the following:" 
  echo "       en fr de ja"
  echo ""
  echo "<Platforms> = Comma delimited of 1 or more of the following:"
  echo "       sparc_solaris parisc_hpux ppc_aix"
  echo ""
  echo "Example:   install.sh /app/fm7 en,fr sparc_solaris"
}


FRAMEDIR="$1"
HSLANGS="$2"
PLATFORMS="$3"
DESTDIR=$FRAMEDIR
SRCDIR=`pwd`

if [ $# = 3 ]; then
  NOOP="noop"
else
 usage;
 exit 1
fi


PRODUCT="WebWorks Publisher Standard Edition"

LANGS="usenglish francais deutsch japanese"

echo "${PRODUCT} Setup"

cd ${FRAMEDIR}

echo ""

echo "Extracting - please wait..."

# due to hp must test for case
goerrortar=0
webtar=wpubse.tar
[ ! -r $SRCDIR/$webtar ] && {
      # Try adding the ";1" string
      if [ -r "$SRCDIR/$webtar;1" ]; then
         webtar="$webtar;1"
      elif [ -r $SRCDIR/WPUBSE.TAR ]; then
         webtar="WPUBSE.TAR"
      elif [ -r "$SRCDIR/WPUBSE.TAR;1" ]; then
         webtar="WPUBSE.TAR;1"
      elif [ -r "$SRCDIR/WPUBSE.TAR.;1" ]; then
         webtar="WPUBSE.TAR.;1"
      else
        #for debug
        echo "Cannot find WebWorks Publisher Standard Edition tar files."
	echo "The installation was not successful."
	exit 1
      fi
}

[ $goerrortar = 0 ] && {
tar xf ${SRCDIR}/${webtar}
}

WWDIR="${DESTDIR}/webworks"


echo ""

#expected params. 1=FMHOME. 2=helpset_langs 3=platforms

#helpset_langs can be en,fr,de,ja
#platforms can be sparc_solaris,parisc_hpux,ppc_aix

#prune install accordingly
if echo "$HSLANGS" | grep "en" > /dev/null ; then
  NOOP="noop"
else
  if [ -d "${WWDIR}/helpdocs/en" ]; then
    rm -r "${WWDIR}/helpdocs/en"
  fi
fi

if echo "$HSLANGS" | grep "fr" > /dev/null ; then
  NOOP="noop"
else
  if [ -d "${WWDIR}/helpdocs/fr" ]; then
    rm -r "${WWDIR}/helpdocs/fr"
  fi
fi

if echo "$HSLANGS" | grep "de" > /dev/null ; then
  NOOP="noop"
else
  if [ -d "${WWDIR}/helpdocs/de" ]; then
    rm -r "${WWDIR}/helpdocs/de"
  fi
fi

if echo "$HSLANGS" | grep "ja" > /dev/null ; then
  NOOP="noop"
else
  if [ -d "${WWDIR}/helpdocs/ja" ]; then
    rm -r "${WWDIR}/helpdocs/ja"
  fi
fi

if echo "$PLATFORMS" | grep "sparc_solaris" > /dev/null ; then
  NOOP="noop"
else
  if [ -d "${WWDIR}/bin/bin.sparc_solaris" ]; then
    rm -r "${WWDIR}/bin/bin.sparc_solaris"
  fi
fi

if echo "$PLATFORMS" | grep "parisc_hpux" > /dev/null ; then
  NOOP="noop"
else
  if [ -d "${WWDIR}/bin/bin.parisc_hpux" ]; then
    rm -r "${WWDIR}/bin/bin.parisc_hpux"
    rm -r "${WWDIR}/patches"
  fi
fi

if echo "$PLATFORMS" | grep "ppc_aix" > /dev/null ; then
  NOOP="noop"
else
  if [ -d "${WWDIR}/bin/bin.ppc_aix" ]; then
    rm -r "${WWDIR}/bin/bin.ppc_aix"
  fi
fi


global;

echo ""

# Setup CJK fonts if necessary
#
if [ -d "${FRAMEDIR}/fminit/fontdir/ja" ]; then
  if [ ! -d "${WWDIR}/lib/gs/cjk/CIDFont" ]; then
    WebWorksPublisher_SetupCJKFonts "${FRAMEDIR}" "${WWDIR}"
  fi
fi

echo "Installation completed successfully! It may now be necessary to run"
echo "${WWDIR}/bin/qlicadm to configure the license server."
echo "Your license key(s) can be found on the FrameMaker CD sleeve."

echo ""
